===================
Configuration Guide
===================

The configuration guide is split into two parts - scenarios and reference.
The scenarios section provides information on configuring Kayobe for different
scenarios. The reference section provides detailed information on many of
Kayobe's configuration options.

.. toctree::
   :maxdepth: 2

   scenarios/index
   reference/index
